@@ -1,30 +1,24 @@
 import os
 import random
-import uuid
-from time import time
 from urllib import request
 
+import progressbar
 import torch
 import torch.nn.functional as F
-import progressbar
 import torchaudio
-
-from ruth_tts_transformer.models.classifier import AudioMiniEncoderWithClassifierHead
-from ruth_tts_transformer.models.diffusion_decoder import DiffusionTts
-from ruth_tts_transformer.models.autoregressive import UnifiedVoice
 from tqdm import tqdm
 
 from ruth_tts_transformer.models.arch_util import TorchMelSpectrogram
+from ruth_tts_transformer.models.autoregressive import UnifiedVoice
+from ruth_tts_transformer.models.classifier import AudioMiniEncoderWithClassifierHead
 from ruth_tts_transformer.models.clvp import CLVP
-from ruth_tts_transformer.models.cvvp import CVVP
-from ruth_tts_transformer.models.random_latent_generator import RandomLatentConverter
+from ruth_tts_transformer.models.diffusion_decoder import DiffusionTts
 from ruth_tts_transformer.models.vocoder import UnivNetGenerator
 from ruth_tts_transformer.utils.audio import wav_to_univnet_mel, denormalize_tacotron_mel
 from ruth_tts_transformer.utils.diffusion import SpacedDiffusion, space_timesteps, get_named_beta_schedule
 from ruth_tts_transformer.utils.tokenizer import VoiceBpeTokenizer
 from ruth_tts_transformer.utils.wav2vec_alignment import Wav2VecAlignment
 
-
 pbar = None
 
 DEFAULT_MODELS_DIR = os.path.join(os.path.expanduser('~'), '.cache', 'tortoise', 'models')
@@ -33,12 +27,9 @@ MODELS = {
     'autoregressive.pth': 'https://huggingface.co/jbetker/tortoise-tts-v2/resolve/main/.models/autoregressive.pth',
     'classifier.pth': 'https://huggingface.co/jbetker/tortoise-tts-v2/resolve/main/.models/classifier.pth',
     'clvp2.pth': 'https://huggingface.co/jbetker/tortoise-tts-v2/resolve/main/.models/clvp2.pth',
-    'cvvp.pth': 'https://huggingface.co/jbetker/tortoise-tts-v2/resolve/main/.models/cvvp.pth',
     'diffusion_decoder.pth': 'https://huggingface.co/jbetker/tortoise-tts-v2/resolve/main/.models/diffusion_decoder.pth',
-    'vocoder.pth': 'https://huggingface.co/jbetker/tortoise-tts-v2/resolve/main/.models/vocoder.pth',
-    'rlg_auto.pth': 'https://huggingface.co/jbetker/tortoise-tts-v2/resolve/main/.models/rlg_auto.pth',
-    'rlg_diffuser.pth': 'https://huggingface.co/jbetker/tortoise-tts-v2/resolve/main/.models/rlg_diffuser.pth',
-}
+    'vocoder.pth': 'https://huggingface.co/jbetker/tortoise-tts-v2/resolve/main/.models/vocoder.pth'}
+
 
 def download_models(specific_models=None):
     """
@@ -241,7 +232,7 @@ class TextToSpeech:
                          num_speech_tokens=8192, speech_enc_depth=20, speech_heads=12, speech_seq_len=430,
                          use_xformers=True).cpu().eval()
         self.clvp.load_state_dict(torch.load(get_model_path('clvp2.pth', models_dir)))
-        self.cvvp = None # CVVP model is only loaded if used.
+
 
         self.vocoder = UnivNetGenerator().cpu()
         self.vocoder.load_state_dict(torch.load(get_model_path('vocoder.pth', models_dir), map_location=torch.device('cpu'))['model_g'])
@@ -251,11 +242,6 @@ class TextToSpeech:
         self.rlg_auto = None
         self.rlg_diffusion = None
 
-    def load_cvvp(self):
-        """Load CVVP model."""
-        self.cvvp = CVVP(model_dim=512, transformer_heads=8, dropout=0, mel_codes=8192, conditioning_enc_depth=8, cond_mask_percentage=0,
-                         speech_enc_depth=8, speech_mask_percentage=0, latent_multiplier=1).cpu().eval()
-        self.cvvp.load_state_dict(torch.load(get_model_path('cvvp.pth', self.models_dir)))
 
     def get_conditioning_latents(self, voice_samples, return_mels=False):
         """
@@ -295,15 +281,6 @@ class TextToSpeech:
         else:
             return auto_latent, diffusion_latent
 
-    def get_random_conditioning_latents(self):
-        # Lazy-load the RLG models.
-        if self.rlg_auto is None:
-            self.rlg_auto = RandomLatentConverter(1024).eval()
-            self.rlg_auto.load_state_dict(torch.load(get_model_path('rlg_auto.pth', self.models_dir), map_location=torch.device('cpu')))
-            self.rlg_diffusion = RandomLatentConverter(2048).eval()
-            self.rlg_diffusion.load_state_dict(torch.load(get_model_path('rlg_diffuser.pth', self.models_dir), map_location=torch.device('cpu')))
-        with torch.no_grad():
-            return self.rlg_auto(torch.tensor([0.0])), self.rlg_diffusion(torch.tensor([0.0]))
 
     def tts_with_preset(self, text, preset='fast', **kwargs):
         """
@@ -332,8 +309,6 @@ class TextToSpeech:
             return_deterministic_state=False,
             # autoregressive generation parameters follow
             num_autoregressive_samples=512, temperature=.8, length_penalty=1, repetition_penalty=2.0, top_p=.8, max_mel_tokens=500,
-            # CVVP parameters follow
-            cvvp_amount=.0,
             # diffusion generation parameters follow
             diffusion_iterations=100, cond_free=True, cond_free_k=2, diffusion_temperature=1.0,
             **hf_generate_kwargs):
@@ -359,9 +334,6 @@ class TextToSpeech:
                                  I was interested in the premise, but the results were not as good as I was hoping. This is off by default, but
                                  could use some tuning.
         :param typical_mass: The typical_mass parameter from the typical_sampling algorithm.
-        ~~CLVP-CVVP KNOBS~~
-        :param cvvp_amount: Controls the influence of the CVVP model in selecting the best output from the autoregressive model.
-                            [0,1]. Values closer to 1 mean the CVVP model is more important, 0 disables the CVVP model.
         ~~DIFFUSION KNOBS~~
         :param diffusion_iterations: Number of diffusion steps to perform. [0,4000]. More steps means the network has more chances to iteratively refine
                                      the output, which should theoretically mean a higher quality output. Generally a value above 250 is not noticeably better,
@@ -382,19 +354,14 @@ class TextToSpeech:
         :return: Generated audio clip(s) as a torch tensor. Shape 1,S if k=1 else, (k,1,S) where S is the sample length.
                  Sample rate is 24kHz.
         """
-        deterministic_seed = self.deterministic_state(seed=use_deterministic_seed)
 
         text_tokens = torch.IntTensor(self.tokenizer.encode(text)).unsqueeze(0).to(self.device)
         text_tokens = F.pad(text_tokens, (0, 1))  # This may not be necessary.
         assert text_tokens.shape[-1] < 400, 'Too much text provided. Break the text up into separate segments and re-try inference.'
 
-        auto_conds = None
-        if voice_samples is not None:
-            auto_conditioning, diffusion_conditioning, auto_conds, _ = self.get_conditioning_latents(voice_samples, return_mels=True)
-        elif conditioning_latents is not None:
-            auto_conditioning, diffusion_conditioning = conditioning_latents
-        else:
-            auto_conditioning, diffusion_conditioning = self.get_random_conditioning_latents()
+
+        auto_conditioning, diffusion_conditioning = conditioning_latents
+
         auto_conditioning = auto_conditioning.to(self.device)
         diffusion_conditioning = diffusion_conditioning.to(self.device)
 
@@ -408,7 +375,7 @@ class TextToSpeech:
             self.autoregressive = self.autoregressive.to(self.device)
             if verbose:
                 print("Generating autoregressive samples..")
-            for b in tqdm(range(num_batches), disable=not verbose):
+            for _ in tqdm(range(num_batches), disable=not verbose):
                 codes = self.autoregressive.inference_speech(auto_conditioning, text_tokens,
                                                              do_sample=True,
                                                              top_p=top_p,
@@ -425,42 +392,27 @@ class TextToSpeech:
 
             clip_results = []
             self.clvp = self.clvp.to(self.device)
-            if cvvp_amount > 0:
-                if self.cvvp is None:
-                    self.load_cvvp()
-                self.cvvp = self.cvvp.to(self.device)
+
+
             if verbose:
-                if self.cvvp is None:
-                    print("Computing best candidates using CLVP")
-                else:
-                    print(f"Computing best candidates using CLVP {((1-cvvp_amount) * 100):2.0f}% and CVVP {(cvvp_amount * 100):2.0f}%")
+                print("Computing best candidates using CLVP")
+
             for batch in tqdm(samples, disable=not verbose):
                 for i in range(batch.shape[0]):
                     batch[i] = fix_autoregressive_output(batch[i], stop_mel_token)
-                if cvvp_amount != 1:
                     clvp = self.clvp(text_tokens.repeat(batch.shape[0], 1), batch, return_loss=False)
-                if auto_conds is not None and cvvp_amount > 0:
-                    cvvp_accumulator = 0
-                    for cl in range(auto_conds.shape[1]):
-                        cvvp_accumulator = cvvp_accumulator + self.cvvp(auto_conds[:, cl].repeat(batch.shape[0], 1, 1), batch, return_loss=False)
-                    cvvp = cvvp_accumulator / auto_conds.shape[1]
-                    if cvvp_amount == 1:
-                        clip_results.append(cvvp)
-                    else:
-                        clip_results.append(cvvp * cvvp_amount + clvp * (1-cvvp_amount))
                 else:
                     clip_results.append(clvp)
+
             clip_results = torch.cat(clip_results, dim=0)
             samples = torch.cat(samples, dim=0)
             best_results = samples[torch.topk(clip_results, k=k).indices]
             self.clvp = self.clvp.cpu()
-            if self.cvvp is not None:
-                self.cvvp = self.cvvp.cpu()
+
+
             del samples
 
-            # The diffusion model actually wants the last hidden layer from the autoregressive model as conditioning
-            # inputs. Re-produce those for the top results. This could be made more efficient by storing all of these
-            # results, but will increase memory usage.
+
             self.autoregressive = self.autoregressive.to(self.device)
             best_latents = self.autoregressive(auto_conditioning.repeat(k, 1), text_tokens.repeat(k, 1),
                                                torch.tensor([text_tokens.shape[-1]], device=text_tokens.device), best_results,
@@ -508,19 +460,6 @@ class TextToSpeech:
                 res = wav_candidates[0]
 
             if return_deterministic_state:
-                return res, (deterministic_seed, text, voice_samples, conditioning_latents)
+                return res, (text, voice_samples, conditioning_latents)
             else:
                 return res
-
-    def deterministic_state(self, seed=None):
-        """
-        Sets the random seeds that tortoise uses to the current time() and returns that seed so results can be
-        reproduced.
-        """
-        seed = int(time()) if seed is None else seed
-        torch.manual_seed(seed)
-        random.seed(seed)
-        # Can't currently set this because of CUBLAS. TODO: potentially enable it if necessary.
-        # torch.use_deterministic_algorithms(True)
-
-        return seed
